/** @file veechgroup.x.cpp
 * Executable computing generators and coset-representatives of the veech group.
 *
 * The algorithm itself is implemented in the file veechgruppe.h.
 *
 * @author Karsten Kremer, Gabriela Schmithuesen
 * @version 1.0
 * @date 29.01.2007
 */

/*  This file is part of the Origami-Library, which is a collection
 *  of algorithms that calculate properties of mathematical objects
 *  called "origamis".
 *
 *  Copyright (C) 2007 Karsten Kremer, Gabriela Schmithuesen
 *  Address: Institute for Algebra and Geometry, Fakultaet fuer
 *  Mathematik, Universitaet Karlsruhe, D-76128 Karlsruhe, Germany.
 *  E-mail: karsten.kremer@math.uni-karlsruhe.de, 
 *  schmithuesen@mathematik.uni-karlsruhe.de
 *  or origami@math.uni-karlsruhe.de
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 3
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, see
 *  <http://www.gnu.org/licenses/> or write to the Free
 *  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 *  Boston, MA  02110-1301, USA.
 *
 *  If you publish results you obtained by using this software please
 *  don't forget to give appropriate credit in your publication.
 */
 
#include <iostream>
#include <fstream>
#include <cstdio>
#include <cassert>
#include <list>

#include "veechgruppe.h"
#include "triangulierung.cpp"
#include "path.cpp"
#include "SL2_Z.cpp"
#include "matrix.cpp"
#include "freeGroups.cpp"
#include "graph.cpp"

using namespace std;

void veech(const Graph& g, int stop=0)
{
 	list<SL2_Z_ST>::iterator it;
 
	Veechgruppe kurve(g);
 	if (!kurve.abbruch) cout << endl << endl << "Veechgruppe successfully calculated:"; 
	else cout << "!!! Calculation of the Veech group interrupted !!!" << endl;
	kurve.origami.ausgabe();
	cout  << endl;

	cout << "Cusps:" << endl; 
	kurve.origami.ausgabe_spitzen(); 
	cout << endl;
	
	cout << "Generators of the affine group: " << endl;
	for (it=kurve.affine_gruppe.begin(); it!=kurve.affine_gruppe.end(); it++) {
		cout << *it << endl;
	}
	cout << endl;

}


int main (int argc, char* argv[]) {
	if (argc < 2) {
		cout << "Please insert an origami file (*.ori) as parameter." << endl;
		return 0;
	}
	Graph g(argv[1]);
	cout << endl << "Origami:" << endl;
	cout << g;	
	veech(g);
	return 0;
}
